# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.core.admin.options import ExtendibleModelAdmin

from publieditor.survey.models import Choice, Question, Answer, Category


class ChoiceInline(admin.TabularInline):
    """
    A newforms-admin inline option class for the ``Choice`` model.
    """
    model = Choice
    extra = 0
    fields = ('choice', 'ordering',)


class ChoiceAdmin(ExtendibleModelAdmin):
    list_display = (
        'get_edit_icon',
        'get_question', 'choice',
        'get_delete_icon'
    )
    ordering = ('choice',)
    fieldsets = (
        (_('Additional information'), {
            'classes': ('collapse',),
            'fields': (('date_create', 'date_last_modify', 'creator', 'last_modifier',))
        }),
        (None, {
            'fields': (
                'choice',
            )
        }),
    )

    def get_question(self, obj):
        return obj.question.question
    get_question.admin_order_field = ('question',)
    get_question.short_description = _('question')


class CategoryAdmin(ExtendibleModelAdmin):
    list_display = (
        'get_edit_icon',
        'name',
        'get_delete_icon',
    )
    fieldsets = (
        (_('Additional information'), {
            'classes': ('collapse',),
            'fields': (('date_create', 'date_last_modify', 'creator', 'last_modifier',))
        }),
        (None, {'fields': ('name', 'slug',)}),
    )
    prepopulated_fields = {"slug": ("name",)}


class QuestionInline(admin.StackedInline):
    model = Question
    extra = 0
    fields = ('question', 'qtype', 'required', 'ordering',)


class QuestionAdmin(ExtendibleModelAdmin):
    fieldsets = (
        (_('Additional information'), {
            'classes': ('collapse',),
            'fields': (('date_create', 'date_last_modify', 'creator', 'last_modifier',))
        }),
        (_('Other information'), {
            'classes': ('collapse',),
            'fields': (
                ('choice_num_min', 'choice_num_max'),
            )
        }),
        (None, {'fields': (
            'language', 'qtype', 'category',
            'typology', 'question', 'required',
        )}),
    )
    list_select_related = True
    list_display = (
        'get_edit_icon',
        'typology', 'question', 'get_choices', 'qtype', 'required',
        'get_delete_icon'
    )
    inlines = (ChoiceInline,)


admin.site.register(Question, QuestionAdmin)
admin.site.register(Choice, ChoiceAdmin)
admin.site.register(Category, CategoryAdmin)